@@ -49,7 +49,7 @@ main::splash_screen(0);
 # before the main loop.
 
 use DBI '1.13';
-$VERSION = '1.148';
+$VERSION = '1.210';
 
 # Now enter strict mode
 use strict;
@@ -63,8 +63,7 @@ use File::Basename;
 # Thanks to Sean Kamath :-)
 use File::Spec;
 
-# A hunky clundgy kinda-of-a-thing
-# to handle screen resizing
+# A hunky clundgy kinda-of-a-thing to handle screen resizing
 
 use Tk::DialogBox;
 use Tk::Balloon;
@@ -509,12 +508,16 @@ if ((!defined($main::orac_curr_db_typ)) ||
    $main::orac_curr_db_typ = main::select_dbtyp(1);
 }
 
+# 1.1.50 Change for Tom, to prevent splash screen interfering with login.
+
+main::destroy_splash();
+
+# Now we go to Login, and get the required database
+
 main::get_db();
 
 # Here we go, lights, cameras, action!
 
-main::destroy_splash();
-
 MainLoop();
 
 # Clear out everything before exiting, and then draw
@@ -1069,7 +1072,7 @@ sub select_dbtyp {
 
    # A successful connection means we store the variable for later
 
-   # Pick up the standard DBA user for the particular database
+   # Pick up the standard user for the particular database
    ($main::sys_user,$main::v_db) = get_dba_user($loc_db);
    main::fill_defaults($loc_db, 
                        $main::sys_user, 
@@ -1084,7 +1087,7 @@ sub select_dbtyp {
 
 =head2 get_dba_user
 
-Picks up the typical DBA user for the particular database.
+Picks up the typical user for the particular database.
 
 =cut
 
@@ -1094,7 +1097,7 @@ sub get_dba_user {
    my $dba_user;
    my $new_db;
 
-   # Picks up the typical DBA user for the particular database
+   # Picks up the typical user for the particular database
 
    my $first_place = File::Spec->catfile($main::orac_home, 'all_dbs.txt');
    my $second_place = File::Spec->catfile($FindBin::RealBin, 'config');
@@ -1353,7 +1356,14 @@ sub config_menu {
    # Initialize variables to prevent
    # warnings
 
-   my $file = "$FindBin::RealBin/menu/$main::orac_curr_db_typ/menu.txt";
+   my $menu_file_name = "menu.txt";
+   if ($main::orac_curr_db_typ eq "Oracle"){
+      if (!$main::current_db->dba_user){
+         $menu_file_name = "menu_dev.txt";
+      }
+   }
+   my $file = "$FindBin::RealBin/menu/$main::orac_curr_db_typ/" .
+              $menu_file_name;
    open(MENU_F, $file) or warn qq{Unable to open $file $!};;
    while(<MENU_F>){
 
