@@ -1,4 +1,4 @@
-select distinct table_name
+select distinct index_name
 from   dba_indexes
 where  UPPER(owner) = UPPER( ? )
 order by 1
