@@ -9,10 +9,10 @@ x.extends "Extends",
 x.waits "Waits",
 x.shrinks "Shrinks",
 x.wraps "Wraps"
-from sys.v_$rollstat X,
-sys.v_$rollname R,
-sys.v_$session S,
-sys.v_$transaction T
+from v$rollstat X,
+v$rollname R,
+v$session S,
+v$transaction T
 where t.addr = s.taddr (+)
 and x.usn (+) = r.usn
 and t.xidusn (+) = r.usn
